package com.lzmispt.data.resource.service.metadata.impl;

package .tmp;

import com.alibaba.csp.sentinel.util.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.nacos.common.utils.CollectionUtils;
import com.lzmispt.core.entity.dto.authorize.UserInfoDTO;
import com.lzmispt.core.entity.dto.querymodel.FilterFieldDTO;
import com.lzmispt.core.entity.dto.querymodel.FilterGroupModelDTO;
import com.lzmispt.core.entity.dto.querymodel.FilterModelDTO;
import com.lzmispt.core.entity.dto.querymodel.QueryModelDTO;
import com.lzmispt.core.service.query.IQuery;
import com.lzmispt.data.center.entity.dto.log.CommonLogDTO;
import com.lzmispt.data.center.entity.dto.resource.metadata.EntityItemInfoSearchDTO;
import com.lzmispt.data.center.entity.dto.resource.spatial.ImportSpatialTableDTO;
import com.lzmispt.data.center.entity.dto.standard.metadata.MetadataEntityDataItemDTO;
import com.lzmispt.data.center.entity.enums.BaseSysFieldEnum;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.resource.metadata.DirectoryTreeVO;
import com.lzmispt.data.center.entity.vo.resource.metadata.MetadataFieldVO;
import com.lzmispt.data.center.entity.vo.resource.spatial.ImportLayerFieldVO;
import com.lzmispt.data.center.entity.vo.standard.metadata.MetadataTypeVO;
import com.lzmispt.data.resource.client.DataApplyClient;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.dao.metadata.IMetadataDao;
import com.lzmispt.data.resource.entity.dto.metadata.SaveMetadataEntityDTO;
import com.lzmispt.data.resource.entity.dto.resanddata.ResAndDataDirectoryDTO;
import com.lzmispt.data.resource.entity.dto.resanddata.ResAndDataEntityDTO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataDirectoryPO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityInfoItemPO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityPO;
import com.lzmispt.data.resource.manager.metadata.MetadataManager;
import com.lzmispt.data.resource.service.history.HistoryTableManager;
import com.lzmispt.data.resource.service.metadata.IInfoItem;
import com.lzmispt.data.resource.service.metadata.IResAndDataDirEntity;
import com.lzmispt.data.resource.service.metadata.IResAndDataResource;
import com.lzmispt.data.resource.service.metadata.ISpatialTable;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.database.IManage;
import com.lzmispt.dcbase.databasestruct.DataStructProvider;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.sysfield.SysFieldHelper;
import com.lzmispt.dcbase.util.HeaderInterceptor;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.exception.BusinessException;
import com.lzmispt.framework.exception.ExceptionUtil;
import com.lzmispt.framework.fconst.FrameConst;
import com.lzmispt.framework.log.LogHelper;
import com.lzmispt.framework.utils.RabbitMQUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

public abstract class SpatialTableManager implements ISpatialTable, IManage {
  @Value("${data-center.primary-key-mode}")
  private String primaryKeyMode;
  
  @Value("${data-center.data-mode:mysql}")
  private String dbType;
  
  @Autowired
  private IQuery query;
  
  @Autowired
  private DataApplyClient applyClient;
  
  @Autowired
  private DataStandardClient standardClient;
  
  @Autowired
  private IResAndDataDirEntity iResAndDataDirEntity;
  
  @Autowired
  IResAndDataResource iResAndDataResource;
  
  @Autowired
  HistoryTableManager historyTableManager;
  
  private static DataStandardClient DATA_STANDARD_CLIENT;
  
  @Autowired
  public void setDataStandardClient(DataStandardClient dataStandardClient) {
    DATA_STANDARD_CLIENT = dataStandardClient;
  }
  
  public ResultEntity<List<DirectoryTreeVO>> importSpatialTable(List<ImportSpatialTableDTO> tables, String tokenId) {
    if (CollectionUtils.isEmpty(tables))
      return ResultEntity.successMessage(new ArrayList()); 
    Map<String, MetadataTypeVO> dataTypeMap = (Map<String, MetadataTypeVO>)((List)this.standardClient.getMetadataTypeList(getDefaultCode(), tokenId).getObj()).stream().collect(Collectors.toMap(MetadataTypeVO::getDataTypeName, Function.identity(), (k1, k2) -> k2));
    ImportSpatialTableCache cache = new ImportSpatialTableCache(dataTypeMap, getDefaultCode(), tokenId);
    try {
      List<DirectoryTreeVO> result = importSpatialTable(tables, cache);
      return ResultEntity.successMessage(result);
    } catch (BusinessException e) {
      return ResultEntity.errorMessage(e.getCode(), e.getMsg());
    } catch (Exception e) {
      LogHelper.error("导入空间表异常，参数：" + JSON.toJSONString(tables), ExceptionUtil.getStackTraceMsg(e));
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_IMPORT_SPATIAL_TABLE_FAILED.getCode()), StatusCodeEnum.DATA_RESOURCE_IMPORT_SPATIAL_TABLE_FAILED.getMessage());
    } 
  }
  
  public ResultEntity<List<MetadataFieldVO>> getEntityInfoItemsByEntityIdAndQuery(String platCode, String tokenId, EntityItemInfoSearchDTO queryModelDTO) {
    List<MetadataFieldVO> metadataFieldVOList = new ArrayList<>();
    if (queryModelDTO != null)
      queryModelDTO.setPlatCode(platCode); 
    String whereSql = getWhereSqlByEntityItemInfoSearchDTO(queryModelDTO);
    if (!StringUtils.isEmpty(queryModelDTO.getEntityId())) {
      MetadataEntityPO metadataEntityPO = ((IMetadataDao)ServiceUtil.getMetadataDao(platCode, IMetadataDao.class)).selectEntityByEntityId(queryModelDTO.getEntityId());
      if (metadataEntityPO == null)
        return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_NO_FOUND_DATA_RESOURCE_ENTITY.getCode()), StatusCodeEnum.DATA_RESOURCE_NO_FOUND_DATA_RESOURCE_ENTITY.getMessage()); 
      List<MetadataEntityInfoItemPO> metadataEntityInfoItemPOList = getMetadataEntityInfoItemPOListByWhere(whereSql, queryModelDTO, metadataEntityPO, tokenId, queryModelDTO.getIsResources());
      if (CollectionUtils.isNotEmpty(metadataEntityInfoItemPOList))
        for (MetadataEntityInfoItemPO metadataEntityInfoItem : metadataEntityInfoItemPOList) {
          MetadataFieldVO metadataFieldVO = new MetadataFieldVO();
          BeanUtils.copyProperties(metadataEntityInfoItem, metadataFieldVO);
          metadataFieldVO.setInEntityOrder(metadataEntityInfoItem.getInfoItemOrder());
          metadataFieldVO.setInfoItemDescription(metadataEntityInfoItem.getDescription());
          metadataFieldVOList.add(metadataFieldVO);
        }  
    } 
    return ResultEntity.successMessage(metadataFieldVOList);
  }
  
  public List<MetadataEntityInfoItemPO> getMetadataEntityInfoItemPOListByWhere(String whereSql, EntityItemInfoSearchDTO entityItemInfoSearchDTO, MetadataEntityPO metadataEntityPO, String tokenId, Integer isRes) {
    if (StringUtils.isEmpty(whereSql))
      return ((IInfoItem)ServiceUtil.getInfoItemManager(getDefaultCode(), IInfoItem.class)).getEntityInfoItemsByEntityId(metadataEntityPO.getEntityId(), getDefaultCode(), isRes, tokenId); 
    return ((IMetadataDao)ServiceUtil.getMetadataDao(entityItemInfoSearchDTO.getPlatCode(), IMetadataDao.class)).getEntityInfoItemsByEntityIdAndQuery(metadataEntityPO.getEntityId(), whereSql);
  }
  
  private List<DirectoryTreeVO> importSpatialTable(List<ImportSpatialTableDTO> tables, ImportSpatialTableCache cache) throws Exception {
    List<DirectoryTreeVO> resultList = new ArrayList<>();
    for (ImportSpatialTableDTO table : tables) {
      ImportTableInfo tableInfo = new ImportTableInfo(table, cache);
      if (table.getLayerName().contains("'") || table.getLayerName().contains("`"))
        throw new BusinessException(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_CONTAINS_SPECIAL_CHARACTERS_NO_IMPORT.getCode()), "表【" + table
            .getLayerName() + "】无法导入，表名中不能包含特殊字符 '`"); 
      ResultEntity<List<ImportLayerFieldVO>> importLayerField = this.applyClient.getImportLayerField(table, getDefaultCode(), cache.getTokenId());
      if (!Objects.equals(importLayerField.getCode(), Integer.valueOf(0)))
        throw new BusinessException(importLayerField.getCode(), importLayerField.getMsg()); 
      List<ImportLayerFieldVO> fields = (List<ImportLayerFieldVO>)importLayerField.getObj();
      checkImport(tableInfo, fields);
      executeCreate(tableInfo, fields, cache.getTokenId());
      DirectoryTreeVO directoryTreeVO = new DirectoryTreeVO();
      BeanUtils.copyProperties(tableInfo.getDirectory(), directoryTreeVO);
      resultList.add(directoryTreeVO);
      logImport(table.getLayerName(), getDefaultCode(), cache.getTokenId());
    } 
    return resultList;
  }
  
  private void executeCreate(ImportTableInfo tableInfo, List<ImportLayerFieldVO> fields, String tokenId) throws Exception {
    MetadataDirectoryPO directory = tableInfo.getDirectory();
    ResAndDataDirectoryDTO resAndDataDirectoryDTO = new ResAndDataDirectoryDTO();
    BeanUtils.copyProperties(directory, resAndDataDirectoryDTO);
    MetadataManager.insertMetadataDirectory(resAndDataDirectoryDTO, getDefaultCode(), DCConst.DataResourceCategory.DATA);
    MetadataEntityPO entity = tableInfo.getEntity();
    SaveMetadataEntityDTO saveMetadataEntityDTO = new SaveMetadataEntityDTO();
    BeanUtils.copyProperties(entity, saveMetadataEntityDTO);
    saveMetadataEntityDTO.setPlatCode(getDefaultCode());
    saveMetadataEntityDTO.setTokenId(tokenId);
    saveMetadataEntityDTO.setDataResourceCategory(DCConst.DataResourceCategory.DATA);
    saveMetadataEntityDTO.setDirectoryId(directory.getDirectoryId());
    ResAndDataEntityDTO resAndDataEntityDTO = new ResAndDataEntityDTO();
    BeanUtils.copyProperties(entity, resAndDataEntityDTO);
    ResAndDataEntityDTO saveCommonMetadataEntity = MetadataManager.saveCommonMetadataEntity(resAndDataEntityDTO, saveMetadataEntityDTO.getPlatCode(), saveMetadataEntityDTO.getDataCategory(), saveMetadataEntityDTO.getTokenId());
    List<MetadataEntityInfoItemPO> existInfoItemList = createCustomInfoItemAndDataItem(saveCommonMetadataEntity, fields, tableInfo.getCache());
    createSysInfoItemAndDataItem(tableInfo, existInfoItemList, tableInfo.getCache());
    this.historyTableManager.saveHistoryTable(tableInfo.getProvider(), tableInfo.getEntity().getEntityId(), null, tableInfo.getTableName(), getDefaultCode(), tableInfo.getCache().getTokenId(), DCConst.TableType.SPATIAL_TABLE, DCConst.DataResourceCategory.DATA);
  }
  
  private void checkImport(ImportTableInfo tableInfo, List<ImportLayerFieldVO> fields) {
    ImportSpatialTableDTO table = tableInfo.getTable();
    ImportSpatialTableCache cache = tableInfo.getCache();
    MetadataDirectoryPO parentDirectory = tableInfo.getParentDirectory();
    Map<String, Object> map = new HashMap<>();
    map.put("directoryName", table.getLayerAliasName());
    map.put("directoryType", DCConst.MetadataDirectoryType.SPATIAL_TABLE);
    map.put("dataCategory", parentDirectory.getDataCategory());
    if (((IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class)).checkExistsDirectory(map) > 0)
      throw new BusinessException(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_DATA_RESOURCE_EXISTS_NO_IMPORT.getCode()), "空间表名【" + table.getLayerAliasName() + "】已经存在，不能重复导入"); 
    List<MetadataEntityPO> entityList = cache.getEntityList(parentDirectory.getDataCategory());
    if (entityList.stream().anyMatch(task -> task.getEntityTableName().equals(table.getLayerName())))
      throw new BusinessException(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_SPATIAL_TABLE_NAME_EXIST.getCode()), String.format(StatusCodeEnum.DATA_RESOURCE_SPATIAL_TABLE_NAME_EXIST.getMessage(), new Object[] { table.getLayerName() })); 
    DataStructProvider provider = cache.getProvider(table.getDatasourceId(), tableInfo.getSchema());
    ResultEntity<Boolean> checkHistoryTableName = this.historyTableManager.checkHistoryTableName(provider, table.getLayerName(), true, getDefaultCode(), DCConst.TableType.DATATABLE);
    if (!Objects.equals(checkHistoryTableName.getCode(), Integer.valueOf(0)))
      throw new BusinessException(checkHistoryTableName.getCode(), checkHistoryTableName.getMsg().replaceFirst("数据表", "空间表")); 
    List<ImportLayerFieldVO> businessKeys = (List<ImportLayerFieldVO>)fields.stream().filter(item -> (DCConst.TRUE.equals(item.getIsPrimaryKey()) && !SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.DBID).equalsIgnoreCase(item.getDataItemName()))).collect(Collectors.toList());
    if (getDefaultCode().equals("Collection") && 
      CollectionUtils.isEmpty(businessKeys))
      throw new BusinessException(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_NO_PRIMARY_KEY_NO_IMPORT.getCode()), "表【" + table.getLayerName() + "】中没有主键，不能导入"); 
    StringBuilder errorFieldNames = new StringBuilder();
    for (ImportLayerFieldVO col : businessKeys) {
      if (DCConst.TRUE.equals(col.getIsPrimaryKey()) && SysFieldHelper.fileSysFieldContains(col.getDataItemName().toLowerCase())) {
        if (StringUtils.hasText(errorFieldNames.toString()))
          errorFieldNames.append("、"); 
        errorFieldNames.append(col.getDataItemName());
      } 
    } 
    if (StringUtils.hasText(errorFieldNames.toString()))
      throw new BusinessException(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_PRIMARY_KEY_SAME_NAME_FILE_TABLE_SYNC.getCode()), "物理字段名称【" + errorFieldNames + "】为主键时不能和文件表内置字段相同"); 
  }
  
  public List<MetadataEntityInfoItemPO> createCustomInfoItemAndDataItem(ResAndDataEntityDTO entity, List<ImportLayerFieldVO> fields, ImportSpatialTableCache cache) {
    List<MetadataEntityDataItemDTO> dataItemList = new ArrayList<>();
    List<MetadataEntityInfoItemPO> result = new ArrayList<>();
    for (ImportLayerFieldVO field : fields) {
      MetadataEntityDataItemDTO tempDataItem = new MetadataEntityDataItemDTO();
      tempDataItem.setDataItemId((Long)WorkerId.getNextId(Long.class));
      tempDataItem.setDataLength(field.getDataLength());
      tempDataItem.setDataScale(field.getDataScale());
      tempDataItem.setDescription(field.getInfoItemDescription());
      tempDataItem.setDataItemCnName(field.getDataItemCNName());
      tempDataItem.setDataItemName(field.getDataItemName());
      tempDataItem.setDataType(field.getDataType());
      tempDataItem.setUserId(entity.getUserId());
      tempDataItem.setOrganizationId(entity.getOrganizationId());
      tempDataItem.setDataItemType("0");
      tempDataItem.setIsDelete(DCConst.FALSE);
      tempDataItem.setIsRequired(field.getIsRequired());
      dataItemList.add(tempDataItem);
      MetadataEntityInfoItemPO infoItem = new MetadataEntityInfoItemPO();
      infoItem.setInfoItemId((Long)WorkerId.getNextId(Long.class));
      infoItem.setEntityId(entity.getEntityId());
      infoItem.setInfoItemName(tempDataItem.getDataItemCnName());
      infoItem.setDataItemId(tempDataItem.getDataItemId());
      infoItem.setDataItemName(tempDataItem.getDataItemName());
      infoItem.setIsPrimaryKey(field.getIsPrimaryKey());
      infoItem.setIsRequired(field.getIsRequired());
      infoItem.setInfoItemStatus(DCConst.InfoItemStatus.VERIFY);
      infoItem.setIsReference(DCConst.FALSE);
      infoItem.setInfoItemType(DCConst.InfoItemType.NORMAL);
      infoItem.setDescription(field.getInfoItemDescription());
      infoItem.setInfoItemOrder(field.getInEntityOrder());
      infoItem.setCreateTime(new Date());
      infoItem.setUpdateTime(new Date());
      infoItem.setUserId(entity.getUserId());
      infoItem.setOrganizationId(entity.getOrganizationId());
      infoItem.setIsDelete(DCConst.FALSE);
      infoItem.setDataType(field.getDataType());
      infoItem.setDataLength(field.getDataLength());
      infoItem.setDataScale(field.getDataScale());
      MetadataManager.saveCommonField(infoItem, entity.getDirectoryId(), entity.getEntityId(), getDefaultCode(), DCConst.DataResourceCategory.DATA, ImportSpatialTableCache.access$000(cache), null);
      result.add(infoItem);
    } 
    if (!CollectionUtils.isEmpty(dataItemList))
      this.standardClient.batchAddMetadataEntityDataItemList(dataItemList, getDefaultCode(), cache.getTokenId()); 
    return result;
  }
  
  public void createSysInfoItemAndDataItem(ImportTableInfo tableInfo, List<MetadataEntityInfoItemPO> existInfoItemList, ImportSpatialTableCache cache) throws Exception {
    MetadataEntityPO entity = tableInfo.getEntity();
    DataStructProvider provider = tableInfo.getProvider();
    int defaultLength = 50;
    int guidLength = 36;
    boolean isGuid = DCConst.PrimaryKeyMode.GUID.equals(this.primaryKeyMode);
    List<MetadataEntityDataItemDTO> dataItemList = new ArrayList<>();
    String dbidType = getDbidType(provider.getDbType(), isGuid);
    Set<String> exist = (Set<String>)existInfoItemList.stream().filter(item -> SysFieldHelper.sysFieldContains(item.getDataItemName())).map(item -> item.getDataItemName().toLowerCase()).collect(Collectors.toSet());
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.DBID).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.DBID), dbidType, DCConst.FALSE, DCConst.TRUE, (isGuid && provider.getDbType().equals("kingbase")) ? null : Integer.valueOf(36), null);
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.DBID), isGuid ? "String" : "Long", isGuid ? 36 : 0, 0));
    } 
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.START_TIME).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.START_TIME), cache.getDBColumnType(provider.getDbType(), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.START_TIME)), DCConst.FALSE, DCConst.TRUE, null, null);
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.START_TIME), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.START_TIME), 0, 0));
    } 
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.SYNC_STATUS).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.SYNC_STATUS), cache.getDBColumnType(provider.getDbType(), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.SYNC_STATUS)), DCConst.FALSE, DCConst.TRUE, Integer.valueOf(1), Integer.valueOf(0));
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.SYNC_STATUS), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.SYNC_STATUS), 1, 0));
    } 
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.LAST_MODIFY_TIME).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.LAST_MODIFY_TIME), cache.getDBColumnType(provider.getDbType(), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.LAST_MODIFY_TIME)), DCConst.FALSE, DCConst.TRUE, Integer.valueOf(1), Integer.valueOf(0));
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.LAST_MODIFY_TIME), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.LAST_MODIFY_TIME), 0, 0));
    } 
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.USER_NAME).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.USER_NAME), cache.getDBColumnType(provider.getDbType(), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.USER_NAME)), DCConst.FALSE, DCConst.TRUE, Integer.valueOf(50), Integer.valueOf(0));
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.USER_NAME), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.USER_NAME), 50, 0));
    } 
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_ID).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_ID), cache.getDBColumnType(provider.getDbType(), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.INTERFACE_ID)), DCConst.FALSE, DCConst.TRUE, Integer.valueOf(50), Integer.valueOf(0));
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_ID), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.INTERFACE_ID), 50, 0));
    } 
    if (!exist.contains(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_USER_ID).toLowerCase())) {
      provider.addColumn(tableInfo.getTableName(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_USER_ID), cache.getDBColumnType(provider.getDbType(), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.INTERFACE_USER_ID)), DCConst.FALSE, DCConst.TRUE, Integer.valueOf(50), Integer.valueOf(0));
      dataItemList.add(createInfoItemAndDataItem(entity.getEntityId(), cache.getUserInfo(), SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_USER_ID), SysFieldHelper.getBaseSysFieldTypeName(BaseSysFieldEnum.INTERFACE_USER_ID), 50, 0));
    } 
    this.standardClient.batchAddMetadataEntityDataItemList(dataItemList, getDefaultCode(), cache.getTokenId());
  }
  
  private MetadataEntityDataItemDTO createInfoItemAndDataItem(Long entityId, UserInfoDTO user, String itemName, String dataType, int length, int scale) {
    MetadataEntityDataItemDTO tempDataItem = new MetadataEntityDataItemDTO();
    tempDataItem.setDataItemId((Long)WorkerId.getNextId(Long.class));
    tempDataItem.setDataType(dataType);
    tempDataItem.setDataLength(Integer.valueOf(length));
    tempDataItem.setDataScale(Integer.valueOf(scale));
    tempDataItem.setDataItemName(itemName);
    tempDataItem.setDataRule("");
    tempDataItem.setDataRuleDescription("");
    tempDataItem.setDataItemType("0");
    tempDataItem.setUserId(user.getUserId());
    tempDataItem.setOrganizationId(user.getOrganizationId());
    tempDataItem.setIsDelete(DCConst.FALSE);
    tempDataItem.setCreateTime(new Date());
    tempDataItem.setUpdateTime(new Date());
    MetadataEntityInfoItemPO tempInfoItem = new MetadataEntityInfoItemPO();
    tempInfoItem.setInfoItemId((Long)WorkerId.getNextId(Long.class));
    tempInfoItem.setDataItemName(itemName);
    tempInfoItem.setInfoItemType(DCConst.InfoItemType.NORMAL);
    tempInfoItem.setIsPrimaryKey(DCConst.FALSE);
    tempInfoItem.setEntityId(entityId);
    tempInfoItem.setInfoItemOrder(Integer.valueOf(1));
    tempInfoItem.setDataItemId(tempDataItem.getDataItemId());
    tempInfoItem.setInfoItemName(itemName);
    tempInfoItem.setIsRequired(DCConst.FALSE);
    tempInfoItem.setDescription("");
    tempInfoItem.setInfoItemStatus(DCConst.InfoItemStatus.VERIFY);
    tempInfoItem.setIsReference(DCConst.FALSE);
    tempInfoItem.setCreateTime(new Date());
    tempInfoItem.setUpdateTime(new Date());
    tempInfoItem.setIsDelete(DCConst.FALSE);
    tempInfoItem.setUserId(user.getUserId());
    tempInfoItem.setOrganizationId(user.getOrganizationId());
    ((IMetadataDao)ServiceUtil.getMetadataDao(getDefaultCode(), IMetadataDao.class)).insertEntityInfoItem(tempInfoItem);
    return tempDataItem;
  }
  
  private void logImport(String tableName, String platCode, String tokenId) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setLoggerInformation("导入空间表 空间表名称:【" + tableName + "】");
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_SYSTEM);
    logDTO.setLogType(0);
    logDTO.setModule_code(HeaderInterceptor.getModuleCode());
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
  
  private String getDbidType(String dbType, boolean isGuid) {
    String columnType = "";
    if (!isGuid)
      return "bigint"; 
    switch (dbType) {
      case "postgresql":
        return "character varying(36)";
      case "kingbase":
        return "character(36)";
      case "dm":
        return "varchar(36)";
      case "sqlserver":
        return "nvarchar(36)";
    } 
    return "char(36)";
  }
  
  public String getWhereSqlByEntityItemInfoSearchDTO(EntityItemInfoSearchDTO entityItemInfoSearchDTO) {
    QueryModelDTO queryModel = entityItemInfoSearchDTO.getQuery();
    if (queryModel == null)
      queryModel = new QueryModelDTO(); 
    if (!DCConst.TRUE.equals(entityItemInfoSearchDTO.getIsView()))
      queryModel = getFilterSysFieldParam(queryModel); 
    boolean isEscapeStr = false;
    if (this.dbType.equalsIgnoreCase("sqlserver"))
      isEscapeStr = true; 
    String whereSql = (String)this.query.getWhereSqlStr(queryModel, this.dbType, true, isEscapeStr).getObj();
    if (!StringUtil.isEmpty(whereSql) && queryModel.getFilterModel() != null)
      whereSql = " and " + whereSql; 
    return whereSql;
  }
  
  private QueryModelDTO getFilterSysFieldParam(QueryModelDTO queryModelDTO) {
    List<String> sysFields = new ArrayList<>();
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.SYNC_STATUS));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.START_TIME));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.LAST_MODIFY_TIME));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.USER_NAME));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.DBID));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_ID));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.IS_DELETE));
    sysFields.add(SysFieldHelper.getBaseSysFieldName(BaseSysFieldEnum.INTERFACE_USER_ID));
    List<FilterFieldDTO> filterFields = new ArrayList<>();
    FilterFieldDTO filterFieldDTO1 = new FilterFieldDTO();
    filterFieldDTO1.setFieldName("infoitemname");
    filterFieldDTO1.setFieldType(Integer.valueOf(10));
    filterFieldDTO1.setFieldValue(sysFields);
    filterFieldDTO1.setOperationType(Integer.valueOf(90));
    filterFields.add(filterFieldDTO1);
    FilterGroupModelDTO filterGroupModel1 = new FilterGroupModelDTO();
    filterGroupModel1.setFilterFields(filterFields);
    filterGroupModel1.setLogicType(Integer.valueOf(0));
    FilterModelDTO filterModelDTO = queryModelDTO.getFilterModel();
    if (filterModelDTO == null) {
      filterModelDTO = new FilterModelDTO();
      filterModelDTO.setFilterGroupModel(new ArrayList());
    } 
    List<FilterGroupModelDTO> filterGroupModel = filterModelDTO.getFilterGroupModel();
    filterGroupModel.add(filterGroupModel1);
    filterModelDTO.setFilterGroupModel(filterGroupModel);
    queryModelDTO.setFilterModel(filterModelDTO);
    return queryModelDTO;
  }
}
